
```
pip install p2s
```

# General Stats
```
seq 0 100 | p2s
```

# Count
```
seq 0 100 | p2s.count
```

# Mean
```
seq 0 100 | p2s.mean
```

# Standard Deviation
```
seq 0 100 | p2s.std
```

# Quantile (in Percent)
```
seq 0 100 | p2s.q 25
```